@@ -20,7 +20,7 @@ our @EXPORT = qw(
 	
 );
 
-our $VERSION = qv('0.02.01');
+our $VERSION = qv('v0.20.1');
 
 
 # Preloaded methods go here.
@@ -160,7 +160,7 @@ Math::Cryptarithm - Solving simple cryptarithm.
 
 =head1 VERSION
 
-Version 0.02.01
+Version 0.20.1
 
 
 =head1 DESCRIPTION
@@ -236,9 +236,9 @@ Return the possible solutions in "decrypted equations" form. See the section Syn
 
 Currently the module runs slowly when the number of variables is equal to or more than 6. Using a backtracking as the algorithm should improve the performance of the module.
 
-=head2 □ or ?
+=head2 "?"
 
-Allow □ or ? to represent any possible digits. See the related entry(L<https://zh.wikipedia.org/wiki/%E8%9F%B2%E9%A3%9F%E7%AE%97|zh> or L<https://ja.wikipedia.org/wiki/%E8%99%AB%E9%A3%9F%E3%81%84%E7%AE%97|ja>) on Wikipedia.
+Allow "?" to represent arbitary digits. See the related Wikipedia entry (L<zh|https://zh.wikipedia.org/wiki/%E8%9F%B2%E9%A3%9F%E7%AE%97> or L<ja|https://ja.wikipedia.org/wiki/%E8%99%AB%E9%A3%9F%E3%81%84%E7%AE%97>) using "square box" representing any possible digits.
 
 =head2 setLeadingZeros($symbol)
 
